@@ -12,6 +12,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+
 import json
 import logging
 import os
@@ -130,12 +131,13 @@ class OrchestrationDeployAction(base.TripleOAction):
         return actions.Result(data=body_json, error=error)
 
 
-class DeployStackAction(templates.ProcessTemplatesAction):
+class DeployStackAction(base.TripleOAction):
     """Deploys a heat stack."""
 
     def __init__(self, timeout, container=constants.DEFAULT_CONTAINER_NAME,
                  skip_deploy_identifier=False):
-        super(DeployStackAction, self).__init__(container)
+        super(DeployStackAction, self).__init__()
+        self.container = container
         self.timeout_mins = timeout
         self.skip_deploy_identifier = skip_deploy_identifier
 
@@ -191,7 +193,10 @@ class DeployStackAction(templates.ProcessTemplatesAction):
                 return actions.Result(error=err_msg)
 
         # process all plan files and create or update a stack
-        processed_data = super(DeployStackAction, self).run(context)
+        process_templates_action = templates.ProcessTemplatesAction(
+            container=self.container
+        )
+        processed_data = process_templates_action.run(context)
 
         # If we receive a 'Result' instance it is because the parent action
         # had an error.
@@ -318,6 +323,45 @@ class OvercloudRcAction(base.TripleOAction):
                                               region_name)
 
 
+class CreateCloudsYamlAction(base.TripleOAction):
+    """Generate the overcloud clouds.yaml contents for a plan
+
+    Given the name of a container, generate the overcloud clouds.yaml
+    contents needed to access the overcloud via the CLI.
+    """
+
+    def __init__(self, container):
+        super(CreateCloudsYamlAction, self).__init__()
+        self.container = container
+
+    def run(self, context):
+        orchestration_client = self.get_orchestration_client(context)
+        swift = self.get_object_client(context)
+        stack = orchestration_client.stacks.get(self.container)
+        env = plan_utils.get_env(swift, self.container)
+        parameter_defaults = env['parameter_defaults']
+        passwords = env['passwords']
+        # Retrive values for cloud from a stack
+        admin_pass = parameter_defaults.get('AdminPassword',
+                                            passwords['AdminPassword'])
+        region_name = parameter_defaults.get('KeystoneRegion', 'regionOne')
+        cloud_name = stack.stack_name
+        auth_url = overcloudrc.get_overcloud_endpoint(stack).replace('/v2.0',
+                                                                     '')
+
+        # Create a dict needed for creating clouds.yaml
+        cloud = {cloud_name: {'auth': {'auth_url': auth_url,
+                                       'project_name': 'admin',
+                                       'project_domain_name': 'Default',
+                                       'username': 'admin',
+                                       'user_domain_name': 'Default',
+                                       'password': admin_pass},
+                              'region_name': region_name,
+                              'identity_api_version': 3}}
+
+        return cloud
+
+
 class DeploymentFailuresAction(base.TripleOAction):
     """Return all of the failures (if any) from deploying the plan
 
