@@ -101,14 +101,17 @@ def get_undercloud_registry():
     ctlplane_hostname = '.'.join([socket.gethostname().split('.')[0],
                                   'ctlplane'])
     cmd = ['getent', 'hosts', ctlplane_hostname]
-    process = subprocess.Popen(cmd, stdout=subprocess.PIPE)
+    process = subprocess.Popen(cmd, stdout=subprocess.PIPE,
+                               universal_newlines=True)
     out, err = process.communicate()
 
     if process.returncode != 0:
-        raise ImageUploaderException('No entry for %s in /etc/hosts'
-                                     % ctlplane_hostname)
-
-    address = out.split()[1]
+        LOG.warning('No entry for %s in /etc/hosts. Falling back to use the '
+                    'default (localhost) undercloud registry.'
+                    % ctlplane_hostname)
+        address = 'localhost'
+    else:
+        address = out.split()[1]
 
     return '%s:%s' % (address, '8787')
 
