@@ -27,6 +27,7 @@ from osc_lib.i18n import _
 from oslo_log import log as logging
 from tripleo_common.image import base
 from tripleo_common.image import image_uploader
+from tripleo_common.utils.locks import threadinglock
 
 CONTAINER_IMAGE_PREPARE_PARAM_STR = None
 
@@ -135,7 +136,8 @@ def set_neutron_driver(pd, mapping_args):
 
 
 def container_images_prepare_multi(environment, roles_data, dry_run=False,
-                                   cleanup=image_uploader.CLEANUP_FULL):
+                                   cleanup=image_uploader.CLEANUP_FULL,
+                                   lock=None):
     """Perform multiple container image prepares and merge result
 
     Given the full heat environment and roles data, perform multiple image
@@ -146,10 +148,14 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
 
     :param environment: Heat environment for deployment
     :param roles_data: Roles file data used to filter services
+    :param lock: a locking object to use when handling uploads
     :returns: dict containing merged container image parameters from all
               prepare operations
     """
 
+    if not lock:
+        lock = threadinglock.ThreadingLock()
+
     pd = environment.get('parameter_defaults', {})
     cip = pd.get('ContainerImagePrepare')
     # if user does not provide a ContainerImagePrepare, use the defaults.
@@ -207,7 +213,8 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
             modify_only_with_labels=modify_only_with_labels,
             mirrors=mirrors,
             registry_credentials=creds,
-            multi_arch=multi_arch
+            multi_arch=multi_arch,
+            lock=lock
         )
         env_params.update(prepare_data['image_params'])
 
@@ -222,7 +229,8 @@ def container_images_prepare_multi(environment, roles_data, dry_run=False,
                     cleanup=cleanup,
                     mirrors=mirrors,
                     registry_credentials=creds,
-                    multi_arch=multi_arch
+                    multi_arch=multi_arch,
+                    lock=lock
                 )
                 uploader.upload()
     return env_params
@@ -246,7 +254,7 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                              append_tag=None, modify_role=None,
                              modify_vars=None, modify_only_with_labels=None,
                              mirrors=None, registry_credentials=None,
-                             multi_arch=False):
+                             multi_arch=False, lock=None):
     """Perform container image preparation
 
     :param template_file: path to Jinja2 file containing all image entries
@@ -280,6 +288,8 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
                                  value.
     :param multi_arch: boolean whether to prepare every architecture of
                        each image
+
+    :param lock: a locking object to use when handling uploads
     :returns: dict with entries for the supplied output_env_file or
               output_images_file
     """
@@ -287,6 +297,9 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     if mapping_args is None:
         mapping_args = {}
 
+    if not lock:
+        lock = threadinglock.ThreadingLock()
+
     def ffunc(entry):
         imagename = entry.get('imagename', '')
         if service_filter is not None:
@@ -312,7 +325,8 @@ def container_images_prepare(template_file=DEFAULT_TEMPLATE_FILE,
     manager = image_uploader.ImageUploadManager(
         mirrors=mirrors,
         registry_credentials=registry_credentials,
-        multi_arch=multi_arch
+        multi_arch=multi_arch,
+        lock=lock
     )
     uploader = manager.uploader('python')
     images = [i.get('imagename', '') for i in result]
