@@ -236,7 +236,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'namespace': 'docker.io/tripleomaster',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'v4.0.1-stable-4.0-nautilus-centos-7-x86_64',
+                'ceph_tag': 'v4.0.4-stable-4.0-nautilus-centos-7-x86_64',
                 'ceph_grafana_namespace': 'docker.io/grafana',
                 'ceph_grafana_image': 'grafana',
                 'ceph_grafana_tag': 'latest',
@@ -928,6 +928,7 @@ class TestPrepare(base.TestCase):
     @mock.patch('tripleo_common.image.image_uploader.ImageUploadManager',
                 autospec=True)
     def test_container_images_prepare_multi(self, mock_im, mock_cip):
+        mock_lock = mock.MagicMock()
         mapping_args = {
             'namespace': 't',
             'name_prefix': '',
@@ -981,7 +982,8 @@ class TestPrepare(base.TestCase):
             },
         ]
 
-        image_params = kb.container_images_prepare_multi(env, roles_data)
+        image_params = kb.container_images_prepare_multi(env, roles_data,
+                                                         lock=mock_lock)
 
         mock_cip.assert_has_calls([
             mock.call(
@@ -1004,7 +1006,8 @@ class TestPrepare(base.TestCase):
                 registry_credentials={
                     'docker.io': {'my_username': 'my_password'}
                 },
-                multi_arch=False
+                multi_arch=False,
+                lock=mock_lock
             ),
             mock.call(
                 excludes=['nova', 'neutron'],
@@ -1026,7 +1029,8 @@ class TestPrepare(base.TestCase):
                 registry_credentials={
                     'docker.io': {'my_username': 'my_password'}
                 },
-                multi_arch=False
+                multi_arch=False,
+                lock=mock_lock
             )
         ])
 
@@ -1046,6 +1050,7 @@ class TestPrepare(base.TestCase):
     @mock.patch('tripleo_common.image.image_uploader.ImageUploadManager',
                 autospec=True)
     def test_container_images_prepare_multi_dry_run(self, mock_im, mock_cip):
+        mock_lock = mock.MagicMock()
         mapping_args = {
             'namespace': 't',
             'name_prefix': '',
@@ -1094,7 +1099,8 @@ class TestPrepare(base.TestCase):
             },
         ]
 
-        image_params = kb.container_images_prepare_multi(env, roles_data, True)
+        image_params = kb.container_images_prepare_multi(env, roles_data, True,
+                                                         lock=mock_lock)
 
         mock_cip.assert_has_calls([
             mock.call(
@@ -1113,7 +1119,8 @@ class TestPrepare(base.TestCase):
                 modify_vars=None,
                 mirrors={},
                 registry_credentials=None,
-                multi_arch=False
+                multi_arch=False,
+                lock=mock_lock
             ),
             mock.call(
                 excludes=['nova', 'neutron'],
@@ -1131,13 +1138,14 @@ class TestPrepare(base.TestCase):
                 modify_vars={'foo_version': '1.0.1'},
                 mirrors={},
                 registry_credentials=None,
-                multi_arch=False
+                multi_arch=False,
+                lock=mock_lock
             )
         ])
 
         mock_im.assert_called_once_with(mock.ANY, dry_run=True, cleanup='full',
                                         mirrors={}, registry_credentials=None,
-                                        multi_arch=False)
+                                        multi_arch=False, lock=mock_lock)
 
         self.assertEqual(
             {
