@@ -38,16 +38,10 @@ class OvercloudRcTest(base.TestCase):
                                                 "regionTwo")
 
         self.assertIn("OS_PASSWORD=AdminPassword", result['overcloudrc'])
-        self.assertIn("OS_PASSWORD=AdminPassword", result['overcloudrc.v3'])
         self.assertIn("OS_IDENTITY_API_VERSION=3", result['overcloudrc'])
-        self.assertIn("OS_IDENTITY_API_VERSION=3", result['overcloudrc.v3'])
         self.assertIn(overcloudrc.CLOUDPROMPT, result['overcloudrc'])
-        self.assertIn(overcloudrc.CLOUDPROMPT, result['overcloudrc.v3'])
         self.assertIn("OS_AUTH_TYPE=password", result['overcloudrc'])
-        self.assertIn("OS_AUTH_TYPE=password", result['overcloudrc.v3'])
         self.assertIn("OS_AUTH_URL=http://foo.com:8000/",
                       result['overcloudrc'])
-        self.assertIn("OS_AUTH_URL=http://foo.com:8000/",
-                      result['overcloudrc.v3'])
         self.assertIn("OS_REGION_NAME=regionTwo",
                       result['overcloudrc'])
